"use strict";
exports.__esModule = true;
/**
 *
 * @param file
 * @param resizeWidth
 * @param newFileName
 * @returns
 */
var resizer = function (file, resizeWidth, newFileName) {
    return new Promise(function (resolve, reject) {
        if (!file) {
            reject(new Error('No file provided.'));
            return;
        }
        // Create a FileReader
        var reader = new FileReader();
        // Image turned to base64-encoded Data URI
        reader.readAsDataURL(file);
        reader.onload = function (event) {
            var img = new Image(); // Create an image
            img.src = event.target.result; // Result is base64-encoded Data URI
            img.onload = function () {
                // scale the image to resizeWidth and keep aspect ratio
                var scaleFactor = resizeWidth / img.width;
                var elem = document.createElement('canvas');
                elem.width = resizeWidth;
                elem.height = img.height * scaleFactor;
                // draw in canvas
                var ctx = elem.getContext('2d');
                ctx.drawImage(img, 0, 0, elem.width, elem.height);
                // get the base64-encoded Data URI from the resized image
                var srcEncoded = ctx.canvas.toDataURL(file.type, 1);
                // CONVERT RESIZED IMAGE BACK TO IMAGE FILE
                var arr = srcEncoded.split(',');
                var mime = arr[0].match(/:(.*?);/)[1];
                var bstr = Buffer.from(arr[1], 'base64').toString('binary');
                var n = bstr.length;
                var u8arr = new Uint8Array(n);
                while (n--) {
                    u8arr[n] = bstr.charCodeAt(n);
                }
                var resizedFile = new File([u8arr], "".concat(Date.now(), "__").concat(newFileName, ".").concat(file.type.split('/')[1]), {
                    type: mime
                });
                resolve(resizedFile);
            };
        };
        reader.onerror = function () {
            reject(new Error('Failed to read the file.'));
        };
    });
};
exports["default"] = resizer;
//# sourceMappingURL=resizer.js.map